==> groupoffice-com-4.0.97.tar.gz: groupoffice-com-4.0.97/modules/addressbook/language/et.php <==
<?php


$l['name'] = 'Aadressiraamat';
$l['description'] = 'Kõikide kontaktide haldamise moodul.';
$l['allAddressbooks'] = 'Kõik aadressiraamatud';
$lang['common']['addressbookAlreadyExists'] = 'Aadressiraamat, mida proovid lisada, on juba olemas';
$l['notIncluded'] = 'Ära impordi';
$l['comment'] = 'Kommenteeri';
$l['bankNo'] = 'Pangakonto nr'; ;
$l['vatNo'] = 'Reg. nr';
$l['contactsGroup'] = 'Grupp';
$lang['link_type'][2]=$l['contact'] = 'Kontakt';
$lang['link_type'][3]=$l['company'] = 'Ettevõte';
$l['customers'] = 'Kliendid';
$l['suppliers'] = 'Varustajad';
$l['prospects'] = 'Võiamlikud kliendid';
$l['contacts'] = 'Kontaktid';
$l['companies'] = 'Ettevõtted';
$l['newContactAdded']='Uus kontakt lisatud';
$l['newContactFromSite']='Kodulehe vormi kaudu lisati uus kontakt.';
$l['clickHereToView']='Kontakti vaatamiseks vaata siia';
$l['contactFromAddressbook']='Kontakt %s';
$l['companyFromAddressbook']='Ettevõte %s';
$l['defaultSalutation']='Lugupeetud [hr./pr.] {middle_name} {last_name}';
$l['multipleSelected']='Mitu aadressiraamatut valitud';
$l['incomplete_delete_contacts']='Valitud kontaktide kustutamiseks puuduvad sul õigused';
$l['incomplete_delete_companies']='Valitud ettevõtete kostutamiseks puuduvad sul õigused';
$l['emailAlreadyExists']='E-posti aadress on sellele kontaktile juba lisatud';
$l['emailDoesntExists']='E-posti aadressi ei leitud';
$l['imageNotSupported']='Üles laetud pildi formaat ei ole lubatud. Ainult gif, png ja jpg on lubatud';

$l["newSearch"]='Uus otsing';
$l["executeQuery"]='Käivita otsingupäring';
$l["savedQueries"]='Salvestatud otsingupäring';
$l["selectField"]= 'Vali väli';
$l["selectMailingGroup"]='Vali meiligrupp';
$l["cmdFormLabelAddressBooks"]= 'Aadressiraamat';
$l["alphabet"]= 'A,B,C,D,E,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z';
$l["cmdAllFields"]= 'Kõik väljad';
$l["btnAddContact"]= 'Lisa kontakt'	;
$l["btnAddCompany"]= 'Lisa ettevõte';
$l["btnManage"]= 'Halda';
$l["btnDownload"]= 'lae fail alla';
$l["cmdFormSearchFirst"]= 'Otsi= ';
$l["cmdFormSearchSecond"]= ' on= ';
$l["cmdFormSearchThird"]= ' jaoks= ';
$l["cmdFormSearchFourth"]= '(Kasuta wildcardina \'%\') ';
$l["cmdFormLabelTitleInitials"]= 'Tiitel/Initsiaalid';
$l["cmdFormLabelSalutation"]= 'Tervitus';
$l["cmdFormLabelComment"]= 'Kommentaar';
$l["cmdFormCompanyEmptyText"]= 'Palun vali ettevõte';
$l["cmdFieldsetSelectAddressbook"]= 'Vali aadressiramat';
$l["cmdFieldsetPersonalDetails"]= 'Isiklikud andmed';
$l["cmdFieldsetAddress"]= 'Aadress';
$l["cmdFieldsetContact"]= 'Kontakti andmed';
$l["cmdFieldsetWork"]= 'Töö';
$l["cmdPanelContact"]= 'Kontakti andmed';
$l["cmdPanelComments"]= 'Kommentaarid';
$l["cmdContactDialog"]= 'Muuda kontakti';
$l["contact"]= 'Kontakt';
$l["cmdSalutation"]= 'Lugupeetud';
$l["cmdMadam"]= 'proua';
$l["cmdSir"]= 'härra';
$l["btnDownloadTextDocument"]= 'Lae alla tekstifail';
$l["cmdContactDetailsFor"]= 'Isiklikud andmed';
$l["cmdLInkFieldset"]= 'Lingid';
$l["company"]= 'Ettevõte';
$l["cmdCompanyDetailsFor"]= 'Andmed';
$l["cmdPanelCompany"]= 'Ettevõtte andmed';
$l["cmdFormLabelBankNo"]= 'Pangakonto nr';
$l["cmdFormLabelVatNo"]= 'KM kohuslase nr';
$l["cmdFieldsetCompanyDetails"]= 'Ettevõtte andmed';
$l["cmdFieldsetVisitAddress"]= 'Tegelik aadress';
$l["cmdFieldsetPostAddress"]= 'Postiaadress';
$l["cmdCompanyDialog"]= 'Muuda ettevõtet';
$l["cmdPanelEmployees"]= 'Töötajad';
$l["cmdPanelEmployee"]= 'Töötaja';
$l["cmdAllEmployeesForThisCompany"]= 'Kõik selle ettevõtte töötajad';
$l["cmdFieldsetVisitAddress"]= 'Tegelik aadress';
$l["cmdFieldsetPostAddress"]= 'Postiaadress';
$l["cmdManageDialog"]= 'Halda';
$l["cmdAddAddressBook"]= 'Lisa aadressiraamat';
$l["cmdDeleteAddressbook"]= 'Kustuta aadressiraamat';
$l["cmdOwner"]= 'Omanik';
$l["cmdPanelAddressbook"]= 'Aadressiraamatud';
$l["cmdPanelProperties"]= 'Atribuudid';
$l["cmdContactDialog"]= 'Muuda kontakti';
$l["cmdFormLabelFileType"]= 'Faili tüüp';
$l["cmdFormLabelFile"]= 'Fail';	;
$l["cmdFormLabelValueSeperated"]= 'Väärtused eraldatud';
$l["cmdFormLabelValueIncluded"]= 'Väärtused kokku surutult';
$l["cmdFormLabelLinesEnded"]= 'read, mis lõppevad';
$l["cmdUpload"]= 'Lae üles';
$l["cmdImport"]= 'Impordi';
$l["cmdExport"]= 'Ekspordi';
$l["cmdType"]= 'Tüüp';
$l["contacts"]= 'Kontaktid';
$l["companies"]= 'Ettevõtted';
$l["users"]= 'Kasutajad';
$l["strSelectContact"]= 'Vali kontakt';
$l["strSelectCompany"]= 'Vali ettevõte';
$l["noAddressbooks"]= 'Aadressiraamatud puuduvad';
$l["moveAll"]= 'Ettevõte ja kõik selle töötajad viiakse üle uude aadressiraamatusse. Oled kindel, et soovid seda teha?';
$l["addressbook"]= 'Aadressiraamat';
$l["addressbooks"]= 'Aadressiraamatud';
$l["sendMailing"]='Saada postitus';
$l["importSuccess"]='Andmed edukalt imporditud';
$l["searchOnSender"]='Vaata aadressiraamatust';
$l["confirmCreate"]='Kontakt puudub. Kas soovid lisada uut kontakti?';
$l["matchFields"]='Sobita väljad?';
$l["advancedSearch"]='Laiendatud otsing';
$l["defaultAddressFormat"]='Vaikimis aadressiformaat';
$l["defaultSalutation"]='Vaikimis tervitus';
$l["explanationVariables"]='Vaikimisi tervituse selgituse väärtused';
$l["explanationSex"]='Mehe või naise tervitusvormel';
$l["searchQueryName"]='Otsipäringu nimi';
$l["enterSearchQueryName"]='Sisesta otsipäringu nimi:';
$l["photo"]= 'Pilt';
$l["deleteImage"]='Kustuta pilt';
$l["addAllSearchResults"]='Lisa kõik otsingutulemused';
$l["confirmAddAllSearchResults"]='Oled kindel, et soovil kõiki otsingutulemusi aadresside nimekirja lisada?';
$l["moveEmployees"]='Liiguta töötajad';
$l["emailAdded"]='E-posti aadress kontaktile lisatud';
$l["exportWithCompanies"]='Ettevõtetega';
$l["id"]='ID';
$l["exportPermission"]='Ekspordi õigused';
$l["crn"]='Ettevõtte Reg. nr.';
$l["iban"]='IBAN';
$l["unknownEmail"]= 'Tundmatu e-posti aadress';
$l["strUnknownEmail"]= 'E-posti aadress on tundmatu. Kas soovid lisada uut kontakti, integreerida seda olemasolevale kontaktile või tühistada?';

==> groupoffice-com-4.1.7.tar.gz: groupoffice-com-4.1.7/modules/addressbook/language/et.php <==
<?php


$l['name'] = 'Aadressiraamat';
$l['description'] = 'Kõikide kontaktide haldamise moodul.';
$l['allAddressbooks'] = 'Kõik aadressiraamatud';
$lang['common']['addressbookAlreadyExists'] = 'Aadressiraamat, mida proovid lisada, on juba olemas';
$l['notIncluded'] = 'Ära impordi';
$l['comment'] = 'Kommenteeri';
$l['bankNo'] = 'Pangakonto nr'; ;
$l['vatNo'] = 'Reg. nr';
$l['contactsGroup'] = 'Grupp';
$lang['link_type'][2]=$lang['link_type'][3]=$l['customers'] = 'Kliendid';
$l['suppliers'] = 'Varustajad';
$l['prospects'] = 'Võiamlikud kliendid';
$l['newContactAdded']='Uus kontakt lisatud';
$l['newContactFromSite']='Kodulehe vormi kaudu lisati uus kontakt.';
$l['clickHereToView']='Kontakti vaatamiseks vaata siia';
$l['contactFromAddressbook']='Kontakt %s';
$l['companyFromAddressbook']='Ettevõte %s';
$l['multipleSelected']='Mitu aadressiraamatut valitud';
$l['incomplete_delete_contacts']='Valitud kontaktide kustutamiseks puuduvad sul õigused';
$l['incomplete_delete_companies']='Valitud ettevõtete kostutamiseks puuduvad sul õigused';
$l['emailAlreadyExists']='E-posti aadress on sellele kontaktile juba lisatud';
$l['emailDoesntExists']='E-posti aadressi ei leitud';
$l['imageNotSupported']='Üles laetud pildi formaat ei ole lubatud. Ainult gif, png ja jpg on lubatud';

$l["newSearch"]='Uus otsing';
$l["executeQuery"]='Käivita otsingupäring';
$l["savedQueries"]='Salvestatud otsingupäring';
$l["selectField"]= 'Vali väli';
$l["selectMailingGroup"]='Vali meiligrupp';
$l["cmdFormLabelAddressBooks"]= 'Aadressiraamat';
$l["alphabet"]= 'A,B,C,D,E,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z';
$l["cmdAllFields"]= 'Kõik väljad';
$l["btnAddContact"]= 'Lisa kontakt'	;
$l["btnAddCompany"]= 'Lisa ettevõte';
$l["btnManage"]= 'Halda';
$l["btnDownload"]= 'lae fail alla';
$l["cmdFormSearchFirst"]= 'Otsi= ';
$l["cmdFormSearchSecond"]= ' on= ';
$l["cmdFormSearchThird"]= ' jaoks= ';
$l["cmdFormSearchFourth"]= '(Kasuta wildcardina \'%\') ';
$l["cmdFormLabelTitleInitials"]= 'Tiitel/Initsiaalid';
$l["cmdFormLabelSalutation"]= 'Tervitus';
$l["cmdFormLabelComment"]= 'Kommentaar';
$l["cmdFormCompanyEmptyText"]= 'Palun vali ettevõte';
$l["cmdFieldsetSelectAddressbook"]= 'Vali aadressiramat';
$l["cmdFieldsetPersonalDetails"]= 'Isiklikud andmed';
$l["cmdFieldsetAddress"]= 'Aadress';
$l["cmdFieldsetContact"]= 'Kontakti andmed';
$l["cmdFieldsetWork"]= 'Töö';
$l["cmdPanelContact"]= 'Kontakti andmed';
$l["cmdPanelComments"]= 'Kommentaarid';
$l["contact"]= 'Kontakt';
$l["cmdSalutation"]= 'Lugupeetud';
$l["cmdMadam"]= 'proua';
$l["cmdSir"]= 'härra';
$l["btnDownloadTextDocument"]= 'Lae alla tekstifail';
$l["cmdContactDetailsFor"]= 'Isiklikud andmed';
$l["cmdLInkFieldset"]= 'Lingid';
$l["company"]= 'Ettevõte';
$l["cmdCompanyDetailsFor"]= 'Andmed';
$l["cmdPanelCompany"]= 'Ettevõtte andmed';
$l["cmdFormLabelBankNo"]= 'Pangakonto nr';
$l["cmdFormLabelVatNo"]= 'KM kohuslase nr';
$l["cmdFieldsetCompanyDetails"]= 'Ettevõtte andmed';
$l["cmdCompanyDialog"]= 'Muuda ettevõtet';
$l["cmdPanelEmployees"]= 'Töötajad';
$l["cmdPanelEmployee"]= 'Töötaja';
$l["cmdAllEmployeesForThisCompany"]= 'Kõik selle ettevõtte töötajad';
$l["cmdFieldsetVisitAddress"]= 'Tegelik aadress';
$l["cmdFieldsetPostAddress"]= 'Postiaadress';
$l["cmdManageDialog"]= 'Halda';
$l["cmdAddAddressBook"]= 'Lisa aadressiraamat';
$l["cmdDeleteAddressbook"]= 'Kustuta aadressiraamat';
$l["cmdOwner"]= 'Omanik';
$l["cmdPanelAddressbook"]= 'Aadressiraamatud';
$l["cmdPanelProperties"]= 'Atribuudid';
$l["cmdContactDialog"]= 'Muuda kontakti';
$l["cmdFormLabelFileType"]= 'Faili tüüp';
$l["cmdFormLabelFile"]= 'Fail';	;
$l["cmdFormLabelValueSeperated"]= 'Väärtused eraldatud';
$l["cmdFormLabelValueIncluded"]= 'Väärtused kokku surutult';
$l["cmdFormLabelLinesEnded"]= 'read, mis lõppevad';
$l["cmdUpload"]= 'Lae üles';
$l["cmdImport"]= 'Impordi';
$l["cmdExport"]= 'Ekspordi';
$l["cmdType"]= 'Tüüp';
$l["contacts"]= 'Kontaktid';
$l["companies"]= 'Ettevõtted';
$l["users"]= 'Kasutajad';
$l["strSelectContact"]= 'Vali kontakt';
$l["strSelectCompany"]= 'Vali ettevõte';
$l["noAddressbooks"]= 'Aadressiraamatud puuduvad';
$l["moveAll"]= 'Ettevõte ja kõik selle töötajad viiakse üle uude aadressiraamatusse. Oled kindel, et soovid seda teha?';
$l["addressbook"]= 'Aadressiraamat';
$l["addressbooks"]= 'Aadressiraamatud';
$l["sendMailing"]='Saada postitus';
$l["importSuccess"]='Andmed edukalt imporditud';
$l["searchOnSender"]='Vaata aadressiraamatust';
$l["confirmCreate"]='Kontakt puudub. Kas soovid lisada uut kontakti?';
$l["matchFields"]='Sobita väljad?';
$l["advancedSearch"]='Laiendatud otsing';
$l["defaultAddressFormat"]='Vaikimis aadressiformaat';
$l["defaultSalutation"]='Vaikimis tervitus';
$l["explanationVariables"]='Vaikimisi tervituse selgituse väärtused';
$l["explanationSex"]='Mehe või naise tervitusvormel';
$l["searchQueryName"]='Otsipäringu nimi';
$l["enterSearchQueryName"]='Sisesta otsipäringu nimi:';
$l["photo"]= 'Pilt';
$l["deleteImage"]='Kustuta pilt';
$l["addAllSearchResults"]='Lisa kõik otsingutulemused';
$l["confirmAddAllSearchResults"]='Oled kindel, et soovil kõiki otsingutulemusi aadresside nimekirja lisada?';
$l["moveEmployees"]='Liiguta töötajad';
$l["emailAdded"]='E-posti aadress kontaktile lisatud';
$l["exportWithCompanies"]='Ettevõtetega';
$l["id"]='ID';
$l["exportPermission"]='Ekspordi õigused';
$l["crn"]='Ettevõtte Reg. nr.';
$l["iban"]='IBAN';
$l["unknownEmail"]= 'Tundmatu e-posti aadress';
$l["strUnknownEmail"]= 'E-posti aadress on tundmatu. Kas soovid lisada uut kontakti, integreerida seda olemasolevale kontaktile või tühistada?';
